@@ -278,7 +278,8 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 			WithSince("v1.28.0").
 			WithPresets(linter.PresetBugs).
 			WithLoadForGoAnalysis().
-			WithURL("https://github.com/kyoh86/exportloopref"),
+			WithURL("https://github.com/kyoh86/exportloopref").
+			DeprecatedWarning("Since Go1.22 (loopvar) this linter is no longer relevant.", "v1.60.2", "copyloopvar"),
 
 		linter.NewConfig(forbidigo.New(&cfg.LintersSettings.Forbidigo)).
 			WithSince("v1.34.0").
@@ -507,6 +508,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 
 		linter.NewConfig(intrange.New()).
 			WithSince("v1.57.0").
+			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/ckaznocha/intrange").
 			WithNoopFallback(cfg, linter.IsGoLowerThanGo122()),
@@ -725,7 +727,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 
 		linter.NewConfig(tenv.New(&cfg.LintersSettings.Tenv)).
 			WithSince("v1.43.0").
-			WithPresets(linter.PresetStyle).
+			WithPresets(linter.PresetTest).
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/sivchari/tenv"),
 
@@ -747,7 +749,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 
 		linter.NewConfig(thelper.New(&cfg.LintersSettings.Thelper)).
 			WithSince("v1.34.0").
-			WithPresets(linter.PresetStyle).
+			WithPresets(linter.PresetTest).
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/kulti/thelper"),
 
@@ -774,7 +776,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/mvdan/unparam"),
 
-		linter.NewConfig(unused.New(&cfg.LintersSettings.Unused, &cfg.LintersSettings.Staticcheck)).
+		linter.NewConfig(unused.New(&cfg.LintersSettings.Unused)).
 			WithEnabledByDefault().
 			WithSince("v1.20.0").
 			WithLoadForGoAnalysis().
