@@ -39,12 +39,12 @@ mv "temp-${VERSION}/golangci-lint" "./golangci-lint-${VERSION}"
 rm -rf "temp-${VERSION}"
 
 ## Build local version
+## use `go build` to set ldflags (it reduces some performance differences with binaries created by goreleaser)
 
-make build
+go build -trimpath -ldflags '-s -w' -o golangci-lint ./cmd/golangci-lint
 
 ## Run
 
-hyperfine \
---prepare './golangci-lint cache clean' "./golangci-lint run --issues-exit-code 0 --print-issued-lines=false --enable-only ${LINTER}" \
---prepare "./golangci-lint-${VERSION} cache clean" "./golangci-lint-${VERSION} run --issues-exit-code 0 --print-issued-lines=false --enable-only ${LINTER}"
-
+hyperfine --warmup 1 \
+-n 'local' --prepare './golangci-lint cache clean' "./golangci-lint run --issues-exit-code 0 --print-issued-lines=false --enable-only ${LINTER}" \
+-n "${VERSION}" --prepare "./golangci-lint-${VERSION} cache clean" "./golangci-lint-${VERSION} run --issues-exit-code 0 --print-issued-lines=false --enable-only ${LINTER}"
